## Time profiles
The folder contains time profiles of emissions for diurnal, weekly and 
seasonal cycles. The data were originally published by TNO for SNAP
emission categories (Denier van der Gon et al., 2011; Pouliot et al.,
2012) and have been mapped to GNFR categories within the CHE project
(Haussaire et al., 2018).

## References
* Denier van der Gon, Hugo, Carlijn Hendriks, Jeroen Kuenen, Arjo Segers,
  Antoon Visschedijk, Description of current temporal emission patterns and
  sensitivity of predicted AQ for temporal emission patterns, TNO report, EU
  FP7 MACC deliverable report D_D-EMIS_1.3, 2011.
  https://atmosphere.copernicus.eu/sites/default/files/2019-07/MACC_TNO_del_1_3_v2.pdf
* Pouliot, G., Pierce, T, Denier van der Gon, H., Schaap, M., Nopmongcol, U.,
  Comparing Emissions Inventories and Model-Ready Emissions Datasets between
  Europe and North America for the AQMEII Project. Atmospheric Environment
  (AQMEII issue) 53, 4-14, 2012.
* Haussaire, J.-M., Brunner, D., Marshall, J., Prunet, P., Augusti-Panareda, A.,
  Manders, A., Segers, A.J., Denier van der Gon, H., Maenhout, G., Houweling, S.,
  Krol, M.: CHE Deliverable 2.1 - Model systems and simulation configurations,
  Version 2.0, CO2 Human Emissions Project, 2018.
  https://che-project.eu/sites/default/files/2018-04/CHE-D2-1-V2-0.pdf

